Package: phangorn
Title: Phylogenetic Reconstruction and Analysis
Version: 2.3.1
Authors@R: c(person("Klaus", "Schliep", email="klaus.schliep@gmail.com", role = c("aut", "cre")), 
  person("Emmanuel", "Paradis", role = c("aut")), 
  person("Leonardo", "de Oliveira Martins", role = c("aut")), 
  person("Alastair", "Potts", role = c("aut")), 
  person("Tim W.", "White", role = c("aut")),
  person("Cyrill", "Stachniss", role = c("ctb")),
  person("Michelle", "Kendall", email="m.kendall@imperial.ac.uk", role = c("ctb")))
Maintainer: Klaus Schliep <klaus.schliep@gmail.com>
Description: Package contains methods for estimation of phylogenetic trees and
    networks using Maximum Likelihood, Maximum Parsimony, distance methods and
    Hadamard conjugation. Allows to compare trees, models selection and offers
    visualizations for trees and split networks. 
Depends: R (>= 3.2.0), ape (>= 5.0)
Imports: quadprog, igraph (>= 1.0), Matrix, parallel, methods, utils,
        stats, graphics, grDevices, fastmatch, magrittr, Rcpp (>=
        0.12.0)
LinkingTo: Rcpp
Suggests: testthat, seqLogo, seqinr, xtable, flashClust, rgl, knitr,
        rmarkdown, Biostrings
ByteCompile: TRUE
License: GPL (>= 2)
VignetteBuilder: utils, knitr
URL: https://github.com/KlausVigo/phangorn
BugReports: https://github.com/KlausVigo/phangorn/issues
Repository: CRAN
RoxygenNote: 6.0.1
NeedsCompilation: yes
Packaged: 2017-11-01 15:09:49 UTC; klaus
Author: Klaus Schliep [aut, cre],
  Emmanuel Paradis [aut],
  Leonardo de Oliveira Martins [aut],
  Alastair Potts [aut],
  Tim W. White [aut],
  Cyrill Stachniss [ctb],
  Michelle Kendall [ctb]
Date/Publication: 2017-11-01 16:37:56 UTC
Built: R 3.4.1; x86_64-w64-mingw32; 2018-02-05 19:29:12 UTC; windows
Archs: x64
