Package: phangorn
Title: Phylogenetic Reconstruction and Analysis
Version: 2.6.2
Authors@R: c(person("Klaus", "Schliep", email="klaus.schliep@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0003-2941-0161")), 
  person("Emmanuel", "Paradis", role = c("aut"), comment = c(ORCID = "0000-0003-3092-2199")), 
  person("Leonardo", "de Oliveira Martins", role = c("aut"), comment = c(ORCID = "0000-0001-5247-1320")), 
  person("Alastair", "Potts", role = c("aut")), 
  person("Tim W.", "White", role = c("aut")),
  person("Cyrill", "Stachniss", role = c("ctb")),
  person("Michelle", "Kendall", email="m.kendall@imperial.ac.uk", role = c("ctb")), 
  person("Keren", "Halabi", role = c("ctb")),
  person("Richel", "Bilderbeek", role = c("ctb")),
  person("Kristin", "Winchell", role = c("ctb")), 
  person("Liam", "Revell", role = c("ctb")),
  person("Mike", "Gilchrist", role=c("ctb")),
  person("Jeremy", "Beaulieu", role=c("ctb")),
  person("Brian", "O'Meara", role=c("ctb")),
  person("Long", "Qu", role=c("ctb")))
Maintainer: Klaus Schliep <klaus.schliep@gmail.com>
Description: Allows for estimation of phylogenetic trees and networks using 
    Maximum Likelihood, Maximum Parsimony, distance methods and Hadamard 
    conjugation. Offers methods for tree comparison, model selection and
    visualization of phylogenetic networks as described in Schliep et al. (2017)
    <doi:10.1111/2041-210X.12760>. 
Depends: R (>= 3.6.0), ape (>= 5.4)
Imports: quadprog, igraph (>= 1.0), Matrix, parallel, methods, utils,
        stats, graphics, grDevices, fastmatch, magrittr, Rcpp (>=
        1.0.4)
LinkingTo: Rcpp
Suggests: tinytest, seqinr, xtable, rgl, prettydoc, knitr, rmarkdown,
        magick, seqLogo, Biostrings
License: GPL (>= 2)
VignetteBuilder: utils, knitr
biocViews: Software, Technology, QualityControl
URL: https://github.com/KlausVigo/phangorn
BugReports: https://github.com/KlausVigo/phangorn/issues
Repository: CRAN
Encoding: UTF-8
RoxygenNote: 7.1.1
NeedsCompilation: yes
Packaged: 2021-01-11 17:09:32 UTC; klaus
Author: Klaus Schliep [aut, cre] (<https://orcid.org/0000-0003-2941-0161>),
  Emmanuel Paradis [aut] (<https://orcid.org/0000-0003-3092-2199>),
  Leonardo de Oliveira Martins [aut]
    (<https://orcid.org/0000-0001-5247-1320>),
  Alastair Potts [aut],
  Tim W. White [aut],
  Cyrill Stachniss [ctb],
  Michelle Kendall [ctb],
  Keren Halabi [ctb],
  Richel Bilderbeek [ctb],
  Kristin Winchell [ctb],
  Liam Revell [ctb],
  Mike Gilchrist [ctb],
  Jeremy Beaulieu [ctb],
  Brian O'Meara [ctb],
  Long Qu [ctb]
Date/Publication: 2021-03-22 14:20:03 UTC
Built: R 3.6.3; x86_64-w64-mingw32; 2021-03-22 16:51:18 UTC; windows
Archs: x64
